# -*- coding: utf-8 -*-

from odoo import api, fields, models
import base64, requests, json

class User(models.Model):
    _inherit = 'res.users'

    inn = fields.Char(string='ИНН')

class PosOrderNew(models.Model):
   _inherit = 'pos.order'

   UniversalID = fields.Char(string='Банковский идентификатор транзакции', readonly=True)
   UniversalIDRefund = fields.Char(string='Банковский идентификатор транзакции связанной продажи (для возврата)', readonly=True)
   pay_kkm_guid = fields.Char(string='GUID платежа по банковской карте', readonly=True)
   pay_cancel_kkm_guid = fields.Char(string='GUID отмены платежа по банковской карте', readonly=True)
   pay_return_kkm_guid = fields.Char(string='GUID возврата платежа по банковской карте', readonly=True)

   def _order_fields(self, ui_order):
       result = super()._order_fields(ui_order)
       result['UniversalID'] = ui_order.get('UniversalID')
       result['UniversalIDRefund'] = ui_order.get('UniversalIDRefund')
       result['pay_kkm_guid'] = ui_order.get('pay_kkm_guid')
       result['pay_cancel_kkm_guid'] = ui_order.get('pay_cancel_kkm_guid')
       result['pay_return_kkm_guid'] = ui_order.get('pay_return_kkm_guid')
       return result

class PosConfigNew(models.Model):
    _inherit = 'pos.config'

    enable_kkm_server = fields.Boolean(string='KKM Server')
    UrlServer = fields.Char(string='UrlServer', default="http://localhost:5893")
    User = fields.Char(string='Логин', default="Admin")
    Password = fields.Char(string='Пароль', default="1111")
    InnKkm_fiscal = fields.Char(string='ИНН фискального регистратора')
    InnKkm_term = fields.Char(string='ИНН эквайрингового терминала')
    NumDevice_fiscal = fields.Integer(string='Номер фискального регистратора', default=0)
    NumDevice_term = fields.Integer(string='Номер эквайрингового терминала', default=0)
    NotPrint = fields.Boolean(string='Не печатать на бумаге', default=False)
    IsBarCode = fields.Boolean(string='Печатaть штрих-код', default=False)
    XRep = fields.Boolean(string='Печатать Х-отчет', default=True)
    DoubleReceipt = fields.Boolean(string='Печатать два чека', default=False)
    ZRep = fields.Boolean(string='Печатать Z-отчет', default=True)
    CashierName = fields.Many2one('res.users', 'Кассир', index=True, required=True, default=lambda self: self.env.user)
    CashierVATIN = fields.Char(string='ИНН кассира', related='CashierName.inn')
    Detailed = fields.Boolean(string='Полный отчет итогов по картам', default=True)
    UseTerminal = fields.Boolean(string='Использовать терминал', default=True)
    timeout_term = fields.Integer(string='Ожидание терминала, мин', default=3)

    def suggest(self):
        for s in self:
            url = s.UrlServer
            headers = { "Authorization": "Basic " +  base64.b64encode(s.User + ":" + s.Password) }
            data = {
                "Command": "List",
                "NumDevice": 0,
                "InnKkm": "",
                "Active": True,
                "OnOff": True,
                "OFD_Error": False,
            }
            r = requests.post(url, data=json.dumps(data), headers=headers)
            return r.json()
